@@ -1,5 +1,6 @@
-from urllib.parse import urlencode
+import json
 from lcrequests import Request, Response
+from urllib.parse import urlencode
 from typing import TYPE_CHECKING
 
 from pylogcabin.exceptions import (
@@ -10,14 +11,7 @@ from pylogcabin.exceptions import (
     ConsoleAPIServerError,
     ConsoleAPINotFoundError,
 )
-from .tokens import (
-    V4PasetoToken,
-    AspenPortalToken,
-    BeaconPortalToken,
-    ClavisPortalToken,
-    DrawBridgePortalToken,
-    VisionMarketToken,
-)
+from .tokens import V4PasetoToken
 from .typehints import DELETE, GET, HEAD, PATCH, POST, PUT
 if TYPE_CHECKING:
     from lcrequests.tokens import PasetoToken
@@ -107,7 +101,7 @@ class PortalAPI:
             Used for calling special API methods.
         :param params: Data to send as query parameters
         """
-        url = f'{self.url}/'
+        url = self.url if self.url.endswith('/') else f'{self.url}/'
         if cid:
             url = f'{url}{cid}/'
 
@@ -137,7 +131,7 @@ class PortalAPI:
 
         if response.status >= 400:
             try:
-                msg = u','.join(response.json()['errors'])
+                msg = ','.join(json.loads(response.data)['errors'])
             except (ValueError, TypeError, KeyError):
                 if response.reason:
                     msg = response.reason
@@ -382,7 +376,6 @@ class AspenAPI(PortalAPI):
     """
     API_NAME = 'Aspen CA Server API'
     SERVER = 'https://aspen.compassfoundation.io'
-    TOKEN_CLASS = AspenPortalToken
 
 
 class BeaconAPI(PortalAPI):
@@ -391,7 +384,6 @@ class BeaconAPI(PortalAPI):
     """
     API_NAME = 'Beacon MDM API'
     SERVER = 'https://beacon.orbitmobile.io'
-    TOKEN_CLASS = BeaconPortalToken
 
 
 class ClavisAuthAPI(PortalAPI):
@@ -400,7 +392,6 @@ class ClavisAuthAPI(PortalAPI):
     """
     API_NAME = 'Clavis Auth API'
     SERVER = 'https://clavis.compassfoundation.io'
-    TOKEN_CLASS = ClavisPortalToken
 
 
 class DrawBridgeAPI(PortalAPI):
@@ -409,7 +400,6 @@ class DrawBridgeAPI(PortalAPI):
     """
     API_NAME = 'DrawBridge Portal API'
     SERVER = 'https://127.0.0.1:1525'
-    TOKEN_CLASS = DrawBridgePortalToken
 
 
 LogCabinAPI = DrawBridgeAPI
@@ -421,7 +411,6 @@ class VisionMarketAPI(PortalAPI):
     """
     API_NAME = 'Vision Market API'
     SERVER = 'https://market.orbitmobile.io'
-    TOKEN_CLASS = VisionMarketToken
 
 
 __all__ = (
